changeset 35312:2f2f03dac098

(find-tag-noselect): Save the value of tags-file-name before switching buffers, for the case it has a buffer-local value.
author Gerd Moellmann <gerd@gnu.org>
date Mon, 15 Jan 2001 16:37:27 +0000
parents 8476c091d163
children da74bf6b4fd5
files lisp/progmodes/etags.el
diffstat 1 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/etags.el	Mon Jan 15 15:29:54 2001 +0000
+++ b/lisp/progmodes/etags.el	Mon Jan 15 16:37:27 2001 +0000
@@ -820,9 +820,11 @@
   (interactive (find-tag-interactive "Find tag: "))
 
   (setq find-tag-history (cons tagname find-tag-history))
-  ;; Save the current buffer's value of `find-tag-hook' before selecting the
-  ;; tags table buffer.
-  (let ((local-find-tag-hook find-tag-hook))
+  ;; Save the current buffer's value of `find-tag-hook' before
+  ;; selecting the tags table buffer.  For the same reason, save value
+  ;; of `tags-file-name' in case it has a buffer-local value.
+  (let ((local-find-tag-hook find-tag-hook)
+	(tags-file-name tags-file-name))
     (if (eq '- next-p)
 	;; Pop back to a previous location.
 	(if (ring-empty-p tags-location-ring)